pytilities.aop — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »

# pytilities.aop

An aspect oriented utility library

In contrast to most libraries, this library supports giving advice to properties (decorators in general) as well.

Features:

- Giving advice to:
  - type of object:
    - all instances of a class
    - some instances
  - kind of member:
    - any descriptor (function, property, classmethod, ...)
    - a non-existent attribute

Restrictions:

- Cannot give advice to built-in/extension types, e.g. property

See the online user guide for more information.

Contents

- aspects
  - ImmutableAspect
  - create_view()
- commands
- _functions
- Advisor
- AOPMeta
- Aspect
- _AOPDescriptor

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »